"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.completionItemsToList = exports.symbolKindToString = exports.completionItemKindToString = exports.hoverContentsToString = exports.documentationToString = exports.diagnosticTagName = exports.diagnosticSeverityName = exports.cmRange = exports.cmPosition = exports.lspChange = exports.lspRange = exports.lspPosition = void 0;
const vscode_languageserver_protocol_1 = require("vscode-languageserver-protocol");
const string_1 = require("./string");
const lspPosition = ({ line, ch }) => ({
    line,
    character: ch,
});
exports.lspPosition = lspPosition;
const lspRange = (start, end) => ({
    start: (0, exports.lspPosition)(start),
    end: (0, exports.lspPosition)(end),
});
exports.lspRange = lspRange;
const lspChange = (change) => ({
    range: (0, exports.lspRange)(change.from, change.to),
    text: change.text.join("\n"),
});
exports.lspChange = lspChange;
const cmPosition = ({ line, character }) => ({
    line,
    ch: character,
});
exports.cmPosition = cmPosition;
const cmRange = ({ start, end }) => [
    (0, exports.cmPosition)(start),
    (0, exports.cmPosition)(end),
];
exports.cmRange = cmRange;
const diagnosticSeverityName = (severity) => {
    switch (severity) {
        case 1 /* DiagnosticSeverity.Error */:
            return "error";
        case 2 /* DiagnosticSeverity.Warning */:
            return "warning";
        case 3 /* DiagnosticSeverity.Information */:
            return "information";
        case 4 /* DiagnosticSeverity.Hint */:
            return "hint";
    }
};
exports.diagnosticSeverityName = diagnosticSeverityName;
const diagnosticTagName = (tag) => {
    switch (tag) {
        case 1 /* DiagnosticTag.Unnecessary */:
            // Style this with faded text.
            return "unnecessary";
        case 2 /* DiagnosticTag.Deprecated */:
            // Style this with strike through.
            return "deprecated";
    }
};
exports.diagnosticTagName = diagnosticTagName;
const documentationToString = (doc, renderMarkdown = (x) => x) => {
    if (!doc)
        return "";
    if (typeof doc === "string")
        return (0, string_1.escapeHtml)(doc);
    return markupContentToString(doc, renderMarkdown);
};
exports.documentationToString = documentationToString;
const hoverContentsToString = (contents, renderMarkdown) => {
    // Note that MarkedString is considereed deprecated
    // MarkedString[]
    if (Array.isArray(contents)) {
        return contents
            .map((c) => markedStringToString(c, renderMarkdown))
            .join("\n");
    }
    if (vscode_languageserver_protocol_1.MarkedString.is(contents)) {
        return markedStringToString(contents, renderMarkdown);
    }
    return markupContentToString(contents, renderMarkdown);
};
exports.hoverContentsToString = hoverContentsToString;
const markupContentToString = (content, renderMarkdown) => content.kind === "markdown"
    ? renderMarkdown(content.value)
    : (0, string_1.escapeHtml)(content.value);
// Markdown string or code-block with language identifier
const markedStringToString = (m, render) => {
    if (typeof m === "string")
        return render(m);
    // To Markdown code block
    return render(["```" + m.language, m.value, "```"].join("\n"));
};
exports.completionItemKindToString = (() => {
    const kinds = [
        "",
        "text",
        "method",
        "function",
        "constructor",
        "field",
        "variable",
        "class",
        "interface",
        "module",
        "property",
        "unit",
        "value",
        "enum",
        "keyword",
        "snippet",
        "color",
        "file",
        "reference",
        "folder",
        "enum-member",
        "constant",
        "struct",
        "event",
        "operator",
        "type-parameter",
    ];
    return (kind) => kinds[kind !== null && kind !== void 0 ? kind : 0] || "unknown";
})();
exports.symbolKindToString = (() => {
    const kinds = [
        "",
        "file",
        "module",
        "namespace",
        "package",
        "class",
        "method",
        "property",
        "field",
        "constructor",
        "enum",
        "interface",
        "function",
        "variable",
        "constant",
        "string",
        "number",
        "boolean",
        "array",
        "object",
        "key",
        "null",
        "enum-member",
        "struct",
        "event",
        "operator",
        "type-parameter",
    ];
    return (kind) => kinds[kind !== null && kind !== void 0 ? kind : 0] || "unknown";
})();
// > If a `CompletionItem[]` is provided it is interpreted to be complete.
// > So it is the same as `{ isIncomplete: false, items }`
const completionItemsToList = (items) => ({
    items,
    isIncomplete: false,
});
exports.completionItemsToList = completionItemsToList;
//# sourceMappingURL=conversions.js.map